@@ -13,48 +13,44 @@ import coiled
 from .chess_util import ChessUtil
 from dask.distributed import TimeoutError
 import multiprocessing
+from dask import config
 
 class ChessDaskCluster:
     "Class for using dask tasks to parallelize calculation of power of each square"
     client: Client
 
     @staticmethod
-    def get_game_data(result_list):
+    def get_game_data(result_list, ply_count):
         "Preparing the data for all plies in all the games"
 
-        gamedata_mapwhite = []
-        gamedata_mapblack = []
-        gamemax_controlwhite = 0
-        gamemax_controlblack = 0
-        ply_mapwhite = [[0 for x in range(8)] for y in range(8)]
-        ply_mapblack = [[0 for x in range(8)] for y in range(8)]
-        column_index = 0
-        row = []
-        row_index = 0
-        ply_no = 0
+        game_data = {}
+        game_data["white"] = []
+        game_data["black"] = []
+        game_data["max_white_value"] = 0
+        game_data["max_black_value"] = 0
+
+        for i in range(ply_count):
+            ply_mapwhite = [[0 for x in range(8)] for y in range(8)]
+            ply_mapblack = [[0 for x in range(8)] for y in range(8)]
+            game_data["white"].append(ply_mapwhite)
+            game_data["black"].append(ply_mapblack)
         for result in result_list:
+            ply_no = result["ply"]
             square_index = result["square"]
             row = square_index//8
             column = square_index%8
-            if result["white"] > gamemax_controlwhite:
-                gamemax_controlwhite = result["white"]
-            if result["black"] > gamemax_controlblack:
-                gamemax_controlblack = result["black"]
-            ply_mapwhite[7-row][column] = result["white"]
-            ply_mapblack[7-row][column] = result["black"]
-            row_index = row_index + 1
-            if row_index == 8:
-                row_index = 0
-                column_index = column_index + 1
-                if column_index == 8:
-                    column_index = 0
-                    gamedata_mapwhite.append(ply_mapwhite)
-                    gamedata_mapblack.append(ply_mapblack)
-                    ply_no = ply_no + 1
-                    ply_mapwhite = [[0 for x in range(8)] for y in range(8)]
-                    ply_mapblack = [[0 for x in range(8)] for y in range(8)]
-        return {"white": gamedata_mapwhite, "black": gamedata_mapblack,
-                "max_white_value": gamemax_controlwhite, "max_black_value": gamemax_controlblack}
+            if "white" in result:
+                power = result["white"]
+                if power > game_data["max_white_value"]:
+                    game_data["max_white_value"] = power
+                game_data["white"][ply_no][row][column] = result["white"]
+            else:
+                power = result["black"]
+                if power > game_data["max_black_value"]:
+                    game_data["max_black_value"] = power
+                game_data["black"][ply_no][row][column] = result["black"]
+
+        return game_data
 
     @staticmethod
     def analyse_game_in_worker(game_dict):
@@ -73,22 +69,14 @@ class ChessDaskCluster:
         try:
             wait(task_futures, timeout)
             control_list_for_game = worker_client.gather(task_futures)
-            game_data = ChessDaskCluster.get_game_data(control_list_for_game)
+            game_results = []
+            for ply_list in control_list_for_game:
+                game_results.extend(ply_list)
+            game_data = ChessDaskCluster.get_game_data(game_results, tasks_for_game["ply_count"])
             game_data["filename"] = str(game_no) + " " + game.headers["Event"]
         except TimeoutError:
             print("Game timed out: " + str(game_no))
         return game_data
-    
-    @staticmethod
-    def run_in_parallel_in_worker(game_batch, is_local_cluster):
-        if is_local_cluster == True:
-            results = []
-            for game in game_batch:
-                results.append(ChessDaskCluster.analyse_game_in_worker(game))
-            return results
-        else:
-            pool = multiprocessing.Pool()
-            return pool.map(ChessDaskCluster.analyse_game_in_worker, game_batch)
 
     def __init__(self):
         config_file = os.path.join(os.getcwd(), "config", "config.yaml")
@@ -116,9 +104,11 @@ class ChessDaskCluster:
         if self.config_values["timeout_per_game"] is None:
             self.config_values["timeout_per_game"] = 30
 
+        config.set({"distributed.worker.daemon": False})
+
         if self.config_values["use_local_cluster"]:
             cluster = LocalCluster(n_workers=self.config_values["n_workers"],
-                                    threads_per_worker=1)
+                                    threads_per_worker=4)
         else:
             coiled.create_software_environment(name=self.config_values["software_environment_name"],
                                                 pip="requirements.txt")
@@ -143,22 +133,20 @@ class ChessDaskCluster:
             game_master_list.append({"game": game, "game_no": game_no, "timeout": timeout})
             game_no = game_no + 1
         index = 1
-        for game_batch in self.batch(game_master_list, 4):
-            game_futures.append(self.client.submit(ChessDaskCluster.run_in_parallel_in_worker,
-                                                   game_batch, self.config_values["use_local_cluster"]))
+        for game in game_master_list:
+            game_futures.append(self.client.submit(ChessDaskCluster.analyse_game_in_worker,
+                                                   game))
             if index % self.config_values["game_batch_size"] == 0:
                 for future in game_futures:
                     result = future.result()
-                    results.extend(result)
-                print("Completed batches till " + str(index * 4))
+                    if result == None:
+                        pass
+                    else:
+                        results.extend(result)
+                print("Completed games till " + str(index))
             index = index + 1
         for future in game_futures:
             result = future.result()
             results.extend(result)
         print("Completed all")
         return results
-
-    def batch(self, iterable, n=1):
-        l = len(iterable)
-        for ndx in range(0, l, n):
-            yield iterable[ndx:min(ndx + n, l)]
\ No newline at end of file
